@@ -28,8 +28,10 @@
 #endif   
 // frqences
 #include "frequences.h"
-// pour dboguer
 #include "libcollatinus.h"
+#include "felix.h"
+// pour dboguer
+//#include <QDebug>
 /**
  * Bogues : 
  *
@@ -45,7 +47,7 @@
  *     Aide : appel du navigateur par dfaut ;
  *
  * Notes Mac OS X spcifiques :
- *      Q_OS_MAC est definit par Qt si la platforme cible est Mac Os
+ *      Q_OS_MAC est defini par Qt si la platforme cible est Mac Os
  */
 
 // variables
@@ -56,14 +58,15 @@ bool morphologia = true; // autorise/interdit l'affichage des morphologies.
 bool syntaxis = true;
 
 QString enTeteLaTeX (
-    "\\documentclass[12pt]{article}"
-    "\\usepackage[T1]{fontenc}"
-    "\\usepackage[latin1]{inputenc}"
-    "\\usepackage{pslatex}"
-    "\\usepackage{geometry}"
-    "\\usepackage[frenchb]{babel}"
-    "\\geometry{a4paper, left=1in, right=1in, top=1in, bottom=1in}"
-    "\\begin{document}");
+    "\\documentclass[12pt]{article}\n"
+    "\\usepackage[T1]{fontenc}\n"
+    "\\usepackage{ucs}\n"
+    "\\usepackage[utf8x]{inputenc}\n"
+    "\\usepackage{pslatex}\n"
+    "\\usepackage{geometry}\n"
+    "\\usepackage[frenchb]{babel}\n"
+    "\\geometry{a4paper, left=1in, right=1in, top=1in, bottom=1in}\n"
+    "\\begin{document}\n");
 
 QString queueLaTeX ( "\\end{document}");
 
@@ -72,7 +75,9 @@ QString prima (QString l)
     QRegExp re ("^\n?(\\w+)");
     int pos = re.indexIn(l);
     if (pos > -1)
+    {
        return re.cap (1);
+    }
     return "";
 }
 
@@ -108,10 +113,11 @@ QString Editeur::lemmatiseTxt (bool alpha, bool cumVocibus)
     QString Retour; 
     QString item;
     QString uox;
+    QString k;
     while (i.hasNext ())
     {
        uox = i.next ();
-       item = QString::fromStdString (lemmatise (uox.toStdString ()));
+       item = QString::fromStdWString (lemmatise (uox.toStdWString ()));
        //qDebug () << "item :" <<item << ":";
        QString lemma (prima (item));
        if (frequentia (lemma) < minRaritas)
@@ -153,7 +159,6 @@ QString Editeur::lemmatiseTxt_expr (bool alpha)
             C.movePosition (QTextCursor::End, QTextCursor::KeepAnchor); 
         else C.setPosition (tc2.position (), QTextCursor::KeepAnchor); 
         P = new Phrase (C.selectedText ());
-        //emit (copie (P->analyse_et_lemmes ()));
         QStringList * sl = P->analyse_et_lemmes (minRaritas);
         QString l;
         for (int i=0;i<sl->size();i++) 
@@ -183,58 +188,91 @@ void Editeur::mouseMoveEvent (QMouseEvent *event)
 
 void Editeur::mouseReleaseEvent (QMouseEvent *event)
 {
-    /* implmenter la lemmatisation de la slection 
-     * si la touche Maj est enfonce, par exemple,
-     * ou la proposer dans un contextuel.
-     *
-     */
+    // implmenter la lemmatisation de la slection 
+    // si la touche Maj est enfonce, par exemple,
+    // ou la proposer dans un contextuel.
+    // 
+    // 
     // poster un signal  l'autre diteur 
+
     QPoint P = parentWidget()->mapFromGlobal(event->globalPos());
     QTextCursor C = cursorForPosition (P);
     QString mc = motCourant (C);
-    //if (QString(uia).isEmpty ()) return;
-    QString ligne = QString::fromStdString (lemmatise (mc.toStdString ()));
-    ligne.remove (QRegExp ("^\n+"));
-    if (frequentia (prima (ligne)) < minRaritas)
-       return;
-    // ajout ventuel de l'expression
-    if (syntaxis)
+    QString ligne;
+    QString k;
+    QString ancienk;
+    ListeAnalyses analyses = lanalyses (mc.toStdWString ());
+    ListeAnalyses adde;
+    if (mc.at (0).isUpper ())
     {
-        // calculer le numro du mot cliqu 
-        int pos = C.position ();
-        int debut = 0;
-        QTextCursor tc2 = document ()->find (QRegExp ("[\\.\\;\\:\\?\\!]"), C, QTextDocument::FindBackward);
-        if (tc2.isNull ()) tc2 = QTextCursor (document ());
-        debut = tc2.position ();
-        tc2.setPosition (C.position (), QTextCursor::KeepAnchor); 
-        QStringList lm = tc2.selectedText ().split (QRegExp ("\\W+"));
-        int mot_num = -1;
-        foreach (QString elm, lm)
-           if (!elm.isEmpty ()) mot_num++;
-
-        //int mot_num = lm.count () - 1; // -2 risque de faire planter
-        //if (mot_num > 0) mot_num--; // pourquoi ? cf ligne prc.
-        
-        // si la phrase n'est pas encore analyse, provoquer l'analyse
-        if (!phrase_at_pos (pos))
+        adde = lanalyses (mc.toLower ().toStdWString ());
+        uniLanalyses (analyses, adde);
+    }
+	QString sineSuff = mc;
+	sineSuff.remove (QRegExp ("(que|ue|ve|ne)$")); 
+	if (sineSuff != mc)
+	{
+		adde = lanalyses (sineSuff.toStdWString ());
+		uniLanalyses (analyses, adde);
+	}
+    int pos = C.position ();
+    bool syntaxevue = false;
+    for (std::multimap<std::wstring, AnalyseMorpho>::iterator it = analyses.begin ();
+         it != analyses.end (); it++)
+    {
+        k = QString::fromStdWString (it->second.lemma ());
+        if (frequentia (k) < minRaritas)
+            continue;
+        if (k != ancienk)
         {
-             tc2.setPosition (debut); 
-             QTextCursor tc3 = document ()->find (QRegExp ("[\\.\\;\\:\\?\\!]"), tc2);
-             tc2.setPosition (tc3.position (), QTextCursor::KeepAnchor);
-             cree_phrase (tc2.selectedText (), debut, tc3.position ());
+             QTextStream (&ligne) << QString::fromStdWString (entree (it->second.lemma ())->definition ());
+            // QTextStream (&ligne) << "   " << QString::fromStdWString (it->second.morpho ())  << "\n"  ;
+            // ajout ventuel de l'expression
+            if (syntaxis && ! syntaxevue)
+            {
+                syntaxevue = true;
+                int debut = 0;
+                QTextCursor tc2 = document ()->find (QRegExp ("[\\.\\;\\:\\?\\!]"), C, QTextDocument::FindBackward);
+                if (tc2.isNull ()) tc2 = QTextCursor (document ());
+                debut = tc2.position ();
+                tc2.setPosition (C.position (), QTextCursor::KeepAnchor); 
+                QStringList lm = tc2.selectedText ().split (QRegExp ("\\W+"));
+                int mot_num = -1;
+                foreach (QString elm, lm)
+                    if (!elm.isEmpty ()) mot_num++;
+                //int mot_num = lm.count () - 1; // -2 risque de faire planter
+                //if (mot_num > 0) mot_num--; // pourquoi ? cf ligne prc.
+                // si la phrase n'est pas encore analyse, provoquer l'analyse
+                if (!phrase_at_pos (pos))
+                {
+                    tc2.setPosition (debut); 
+                    QTextCursor tc3 = document ()->find (QRegExp ("[\\.\\;\\:\\?\\!]"), tc2);
+                    tc2.setPosition (tc3.position (), QTextCursor::KeepAnchor);
+                    cree_phrase (tc2.selectedText (), debut, tc3.position ());
+                }
+                // appeler l'analyse syntaxique du mot
+                QTextStream (&ligne) << analyse_syntaxique (pos, mot_num, k);
+            }
+            QTextStream (&ligne) << "\n";
+            if (calepino_actif ())
+            {
+                QTextStream (&ligne) << QString::fromStdWString (ambrogio (k.toStdWString ())); 
+            }
+            ancienk = k;
         }
-        // appeler l'analyse syntaxique du mot
-        QTextStream (&ligne) << analyse_syntaxique (pos, mot_num);
+        // ancienk = k;
     }
-    if (calepino_actif ())
+    if (ligne.isEmpty ())
     {
-        QTextStream (&ligne) << QString::fromStdString (ambrogio (prima (ligne).toStdString ())); 
+       ligne = mc + " ?"; 
     }
-    // la forme du texte latin demande ?
-    emit (copie (ligne));
+    emit (copie (ligne, k));
     QTextEdit::mouseReleaseEvent (event);
 }
 
+
+
+
 /**
  * renvoie le mot sous le curseur C
  *
@@ -251,7 +289,7 @@ fenestra::fenestra(QString url)
     actionAuxilium->setShortcut(QKeySequence::HelpContents);
     action_Noua->setShortcut(QKeySequence::New    );
     action_Onerare->setShortcut(QKeySequence::Open   );
-    action_Exire->setShortcut(QKeySequence::Quit   );
+    //action_Exire->setShortcut(QKeySequence::Quit   );
     actionScribere_s_ub->setShortcut(QKeySequence::SaveAs );
     action_Scribere->setShortcut(QKeySequence::Save   );
     actionInuenire->setShortcut(QKeySequence::Find   );
@@ -313,6 +351,8 @@ fenestra::fenestra(QString url)
     font.setWeight(50);
     font.setStrikeOut(false);
     EditFlexio->setFont(font);
+    EditTextus->setFont(font);
+    EditLaTeX->setFont(font);
     #endif
     createActions ();
     // chargement du lexique et du fichier d'exemple
@@ -344,11 +384,13 @@ void fenestra::decollatino ()
 {
     QMessageBox::about(this, tr("De Collatino"),
             tr("COLLATINVS\nLinguae latinae lemmatizatio \n"
-               "Licenti GPL, (c) Yves Ouvrard, annis 2009 - 2011 \n"
+               "Licenti GPL, (c) Yves Ouvrard, annis 2009 - 2012 \n"
                "Versio "VERSION"\n"
                "Gratias illis habeo :\n"
                "William Whitaker,\n"
-               "Jose Luis Redrejo."));
+               "Jose Luis Redrejo,\n"
+               "Georges Khaznadar,"
+               "Matthias Bussonier."));
 }
 
 /**
@@ -361,11 +403,11 @@ bool fenestra::cautio ()
 {
     if (Ed->document()->isModified()
        || EditTextus->document()->isModified() 
-       || EditHtml->document()->isModified()
+       // || EditFelix->document()->isModified()
        || EditLaTeX->document()->isModified() ) 
        {
            int ret = QMessageBox::warning(this, tr("Collatinus"),
-                   tr("Opus tuum scriptum non est.\n"
+                   tr("Opus tuum scriptum non est. "
                       "Id facere uis nunc ?"),
                    QMessageBox::Yes | QMessageBox::Default,
                    QMessageBox::No,
@@ -400,6 +442,7 @@ bool fenestra::capsaminDiscum (const QString &fileName)
         out << endl << endl;
         out << EditTextus->toPlainText ();
     }
+    /*
     else if (ci == 1)
     {
        QString tampon = EditHtml->toHtml ();
@@ -410,10 +453,11 @@ bool fenestra::capsaminDiscum (const QString &fileName)
        EditHtml->clear ();
        EditHtml->insertHtml (tampon);
     }
+    */
     else if (ci == 2)
     {
-       out << enTeteLaTeX;
-       out << Ed->toPlainText ();
+       out << enTeteLaTeX ;
+       out << Ed->toPlainText () << "\\\\\n";
        out << EditLaTeX->toPlainText ();
        out << queueLaTeX;
     }
@@ -509,11 +553,11 @@ bool fenestra::event (QEvent *event)
         // ter crochets et guillemets
         mot = mot.replace (QRegExp ("['\"]"), "");
         QString bulla;
-        if (morphologia) bulla = QString::fromStdString (lemmatiseM (mot.toStdString ()));
-        else bulla = QString::fromStdString (lemmatise (mot.toStdString ()));
+        if (morphologia) bulla = QString::fromStdWString (lemmatiseM (mot.toStdWString ()));
+        else bulla = QString::fromStdWString (lemmatise (mot.toStdWString ()));
         if (frequentia (prima (bulla)) < minRaritas) 
             bulla = "id scire debes"; 
-        QToolTip::showText (helpEvent->globalPos(), bulla, this);
+        QToolTip::showText (helpEvent->globalPos(), bulla.trimmed (), this);
     }
     return QWidget::event (event);
 }
@@ -533,27 +577,33 @@ QString crassaPrima (QString l, int latex=0)
     }
     else
     {
+        // construire la page html
         lineae.replaceInStrings (re, "<b>\\1</b>");
         return lineae.join ("<br/>\n");
     }
 }
 
-void fenestra::recoisLemm (QString l)
+void fenestra::recoisLemm (QString l, QString k)
 {
+    l = l.trimmed ();
     //editeurCourant ()->append (l);
     int ci = tabWidget->currentIndex ();
-    if (ci == 0) 
-        //editeurCourant ()->append (l);
-        EditTextus->append (l);
-    else if (ci == 1)
+    if (ci == 0)
     {
         l = crassaPrima (l); 
-        EditHtml->append (l);
+        EditTextus->append (l);
+    }
+    else if (ci == 1) // Gaffiot
+    {
+        // QString pg;
+        if (k.isEmpty ())
+            spinBox->setValue (page_felix (l));
+        else spinBox->setValue (page_felix (k));
     }
     else if (ci == 2)
     {
         l = crassaPrima (l, 1);
-        EditLaTeX->append (l);
+        EditLaTeX->append (l+"\\\\");
     }
     else if (ci == 3)
     {
@@ -561,13 +611,14 @@ void fenestra::recoisLemm (QString l)
         int pos = re.indexIn(l);
         if (pos > -1)
         {
-            QString k (re.cap (1));
-            Tentree *e = entree (k.toStdString ());
+            // QString k (re.cap (1));
+            Tentree *e = entree (k.toStdWString ());
             EditFlexio->clear ();
             if (!e->est_vide ())
-                EditFlexio->append (QString::fromStdString (flechis (e)));
+                EditFlexio->append (QString::fromStdWString (flechis (e)));
             else EditFlexio->append ("id " + k + " non intellexi.");
         }
+        EditFlexio->setTextCursor(QTextCursor(EditFlexio->document()));
     }
 }
 
@@ -576,7 +627,7 @@ QTextEdit* fenestra::editeurCourant ()
     switch (tabWidget->currentIndex ())
     {
         case 0: return EditTextus;
-        case 1: return EditHtml;
+        case 1: return EditFelix;
         case 2: return EditLaTeX;
         default: return EditFlexio;
     }
@@ -588,7 +639,7 @@ void fenestra::daFichierCourant (const QString &capsaeNomen)
     courant = capsaeNomen;
     Ed->document()->setModified(false);
     EditTextus->document()->setModified(false);
-    EditHtml->document()->setModified(false);
+    //EditHtml->document()->setModified(false);
     EditLaTeX->document()->setModified(false);
     //setWindowModified(false);
 
@@ -617,7 +668,7 @@ void fenestra::noua ()
      {
          Ed->clear ();
          EditTextus->clear ();
-         EditHtml->clear ();
+         // EditFelix->clear ();
          EditLaTeX->clear ();
          vide_phrases ();
          Ed->setFocus ();
@@ -653,7 +704,7 @@ void fenestra::closeEvent(QCloseEvent *event)
 
 void fenestra::lemmatiseTout ()
 {
-    QString (lem) (bool, bool); 
+    //QString (lem) (bool, bool); 
     editeurCourant ()->clear ();
     QString T;
     if (syntaxis) T = Ed->lemmatiseTxt_expr (actionAlphabetice->isChecked ());
@@ -661,11 +712,18 @@ void fenestra::lemmatiseTout ()
                                 actionCum_textus_uocibus->isChecked ());
     int ci = tabWidget->currentIndex ();
     if (ci == 0)
-        EditTextus->append (T);
+    {
+        // EditTextus->append (T.trimmed ());
+        T = crassaPrima (T);
+        EditTextus->insertHtml (T); 
+    }
     else if (ci == 1)
     {
+        /*
         T = crassaPrima (T);
         EditHtml->insertHtml (T); 
+        */
+        // ouvrir EditTextus, y coller la lemmatisation
     }
     else if (ci == 2)
     {
@@ -713,7 +771,7 @@ void fenestra::gallaece ()
 
 void fenestra::calepin ()
 {
-    activeCalepin (true);
+    activeCalepin (actionCalepino->isChecked ());
 }
 
 void fenestra::inuenire (const QString & exp)
@@ -722,7 +780,7 @@ void fenestra::inuenire (const QString & exp)
     if( find_result.hasSelection())
         Ed->setTextCursor(find_result);
     else
-        Ed->setTextCursor(QTextCursor::QTextCursor(Ed->document()));
+        Ed->setTextCursor(QTextCursor(Ed->document()));
 }
 void fenestra::inuenire ()
 {
@@ -790,6 +848,24 @@ void fenestra::change_rarete ()
     else minRaritas = 5;
 }
 
+void fenestra::change_Felix (QString c)
+{
+    int p = page_felix (c);
+    spinBox->setValue (p);
+}
+
+void fenestra::change_page_Felix (int p)
+{
+    if (p > 1702) p = 1702;
+    QString pg;
+    QTextStream (&pg) << "<html><img src=\"" 
+        + QApplication::applicationDirPath () 
+        + "/felix/" << p << ".jpg\"></html>";
+    // TODO : changer avec setText ();
+    EditFelix->setText (pg);
+    EditFelix->setTextCursor(QTextCursor(EditFelix->document()));
+}
+
 void fenestra::vide_texte ()
 {
     vide_phrases ();
@@ -818,7 +894,7 @@ void fenestra::createActions ()
     connect(actionMinores_litteras, SIGNAL(triggered()), Ed, SLOT(zoomOut()));
     connect (actionDe_Collatino, SIGNAL (triggered ()), this, SLOT(decollatino ()));
     connect (actionOmnia_lemmatizare, SIGNAL (triggered ()), this, SLOT(lemmatiseTout ()));
-    connect(Ed, SIGNAL(copie (QString)), this, SLOT(recoisLemm (QString)));
+    connect(Ed, SIGNAL(copie (QString, QString)), this, SLOT(recoisLemm (QString, QString)));
     connect(Ed, SIGNAL(textChanged()), actionVide_texte, SLOT(trigger()));
     connect(actionL_emmata_radere, SIGNAL(triggered()), this, SLOT(lemmataRadere()));
     //connect(action_Lineam_radere, SIGNAL(triggered()), this, SLOT(lineamRadere()));
@@ -836,6 +912,8 @@ void fenestra::createActions ()
     connect(actionSyntaxis, SIGNAL(triggered ()), this, SLOT (change_syntaxe ()));
     connect(tabWidget, SIGNAL(currentChanged (int)), this, SLOT (controleIcone (int)));
     connect(actionMorphologia_in_bullis, SIGNAL(toggled (bool)), this, SLOT(change_morpho (bool)));
+    connect(saisie_felix, SIGNAL(textChanged (QString)), this, SLOT (change_Felix (QString)));
+    connect(spinBox, SIGNAL(valueChanged (int)), this, SLOT (change_page_Felix (int)));
 
     QActionGroup * grLingua = new QActionGroup (this); 
     actionGermanice->setActionGroup (grLingua);
