@@ -22,6 +22,7 @@
 #include "syntaxe.h"
 #include <map>
 #include <list>
+//#include <QDebug>
 
 using namespace std;
 
@@ -136,8 +137,6 @@ int Morphos::getItem ()
  */
 bool Morphos::accepte (Morphos * mb)
 {
-    // qDebug () << "graphie expr:" << graphie <<":";
-    // qDebug () << "graphie Phr :" << mb->getGraphie ();
     QString mbK = mb->getCanon ();
     if (!canon.isEmpty ())
     {
@@ -148,22 +147,23 @@ bool Morphos::accepte (Morphos * mb)
         }
         else
         {
-    
-    
-    
             if (canon != mbK) return false;
         }
 
     }
+    // qDebug () << "mbK:" << mbK << ":" << canon << ":";
     if (graphie.isEmpty ()) return true;
     QStringList eclatsExpr = graphie.split (" ");
     QStringList eclatsP = mb->getGraphie ().split (" ");
     foreach (QString ee, eclatsExpr)
+    {
+        // qDebug () << "ee :" << ee << ":";
         if (eclatsP.indexOf (ee) < 0)
         {
             // qDebug () << mb->getGraphie () << " refuse " << ee;
             return false;
         }
+    }
     // qDebug () << "accepte"; 
     return true;
 }
@@ -218,12 +218,11 @@ Mot::~Mot ()
 
 void Mot::lemmatise ()
 {
-    // TODO gestion des majuscules
-    ListeAnalyses analyses = lanalyses (graphie.toStdString ());
+    ListeAnalyses analyses = lanalyses (graphie.toStdWString ());
     ListeAnalyses adde;
     if (graphie.at (0).isUpper ())
     {
-        adde = lanalyses (graphie.toLower ().toStdString ());
+        adde = lanalyses (graphie.toLower ().toStdWString ());
         uniLanalyses (analyses, adde);
     }
 	// ôter les éventuels suffxes
@@ -231,18 +230,18 @@ void Mot::lemmatise ()
 	sineSuff.remove (QRegExp ("(que|ue|ve|ne)$")); 
 	if (sineSuff != graphie)
 	{
-		adde = lanalyses (sineSuff.toStdString ());
+		adde = lanalyses (sineSuff.toStdWString ());
 		uniLanalyses (analyses, adde);
 	}
 	// enregistrer la lemmatisation
     QString mo;
     QTextStream flux (&mo);
     Morphos * morph;
-	std::string ancienL, nouvoL; 
+	std::wstring ancienL, nouvoL; 
     // convertir le retour des analyses en instances de Morphos
 	if (analyses.empty ())
 		QTextStream (&lemme) << "\n" << graphie << " ?";
-    for (std::multimap<std::string, AnalyseMorpho>::iterator it = analyses.begin ();
+    for (std::multimap<std::wstring, AnalyseMorpho>::iterator it = analyses.begin ();
          it != analyses.end (); it++)
     {
         // cas
@@ -264,12 +263,12 @@ void Mot::lemmatise ()
         
         mo = mo.simplified ();
         morph = new Morphos (mo); 
-        morph->setCanon (QString::fromStdString (it->second.lemma ()));
+        morph->setCanon (QString::fromStdWString (it->second.lemma ()));
         morphos << morph;
         mo.clear ();
 		nouvoL = entree (it->second.lemma ())->doc ();
 		if (nouvoL != ancienL)
-		    QTextStream (&lemme) << "\n" << QString::fromStdString (nouvoL);
+		    QTextStream (&lemme) << "\n" << QString::fromStdWString (nouvoL);
 		ancienL = nouvoL;
     }
 }
@@ -356,7 +355,6 @@ Expression::Expression (QString n)
     {
         QStringList liste = eclats[ie].split ('.');
         Morphos * m = new Morphos (liste[1]);
-        // if (liste[0] == "res") qDebug () << "res trouvé : " << n;
         m->setCanon (liste[0]); 
         if (!liste[2].isEmpty ()) 
         {
@@ -452,7 +450,6 @@ Liste_expr::Liste_expr (QString f)
         Expression * E = new Expression (lin);
         // injection
         expressions.insert (E->lemme_noyau (), E); 
-        //qDebug () << lin;
         lin = in.readLine ();
     }
 }
@@ -464,7 +461,7 @@ Liste_expr::~Liste_expr ()
 
 QList<Expression *> Liste_expr::expr_lemme (QString l)
 {
-    //qDebug () << "liste_expr (" << l << ")";
+    // qDebug () << "liste_expr (" << l << ")";
     return expressions.values (l);    
 }
 
@@ -541,12 +538,17 @@ bool contient (QList<Expression *> liste, Expression * expr)
 Mot * Phrase::motExpr (Morphos * m)
 {
     foreach (Mot * imot, mots)
+    {
         for (int i = 0;i<imot->count_morphos ();i++)
+        {
+            // qDebug () << imot->getMorpho (i)->humain ();
             if ((!imot->estAdopte ()) && m->accepte (imot->getMorpho (i)))
             {
                 imot->setAdopte (true);
                 return imot;
             }
+        }
+    }
     return NULL;
 }
 
@@ -569,12 +571,13 @@ void Phrase::cherche_expressions ()
        {
             // s'il n'est pas noyo potentiel, mot suivant
             QList<Expression *> le = LExpressions->expr_lemme (mot->getCanon (i));
-            //qDebug () << mot->getCanon (i) << " " << le.isEmpty ();
+            // qDebug () << mot->getCanon (i) << " " << le.isEmpty ();
             if (le.isEmpty ()) continue;
             // ici, possibilité de renvoyer toute expression utilisant le mot
             // pour chaque expression potentielle
             foreach (Expression * expr, le)
             {
+                // qDebug () << expr->humain ();
                 initAdoptes ();
                 // pour chaque mot requis de l'expression
                 bool esuiv = false;
@@ -592,10 +595,11 @@ void Phrase::cherche_expressions ()
                 for (int im = 0; im < expr->countMorphos (); im++)
                 {
                     // si aucun des mots repérés n'a la bonne morpho, expr. suivante
+                    // version 2012 : bogue ici.
                     Mot * mota = motExpr (expr->getMorpho (im));
                     if (mota == NULL) 
                     {
-                        //qDebug () << "jaipa";
+                        // qDebug () << "jaipa";
                         esuiv = true;
                         continue;
                     }
@@ -607,7 +611,6 @@ void Phrase::cherche_expressions ()
                     }
                 }
                 if (esuiv) continue;
-                //qDebug () << expr->humain () << " " << liste_expressions.size ();
                 //vérifier l'accord
                 if (avec >= 0 && !accord (de, en, avec)) continue;
                 // ajouter le n° du mot + l'expression à la phrase
@@ -663,10 +666,12 @@ QStringList * Phrase::analyse_et_lemmes (int minRaritas)
          QString lemma (mots[i]->getCanon (0));
          //qDebug () << lemma << " " << frequentia (lemma);
          if (minRaritas <= frequentia (lemma))
-		     retour->append (mots[i]->get_lemme ());
-		 e = expression_no (i); 
-		 if (e != NULL) 
-             retour->append  ("\n   " + QString (0x00B6) + " " + e->getNom () + " : " + e->getDoc ());
+         {
+		     e = expression_no (i); 
+		     if (e != NULL) 
+                 retour->append  (mots[i]->get_lemme () + "\n   " + QString (0x00B6) + " " + e->getNom () + " : " + e->getDoc ());
+             else retour->append (mots[i]->get_lemme ());
+         }
 	}
 	return retour;
 }
@@ -761,16 +766,20 @@ void cree_phrase (QString p, int d, int f)
 }
 
 // appel d'analyse syntaxique
-QString analyse_syntaxique (int p, int mot_no)
+QString analyse_syntaxique (int p, int motNo, QString &canon)
 {
     QString retour;
     Phrase * phr = texte->phrase_pos (p);
     if (phr == NULL) return "";
+    canon = phr->mot_no(motNo)->getCanon (0);
     foreach (Expression * expr, phr->expressions ())
     {
-        if (expr->getPosInP () == mot_no)
+        if (expr->getPosInP () == motNo)
+        {
             // retour précédé du signe unicode '|P' ou 00B6 (182) 
             QTextStream (&retour) << "\n   " << QString (0x00B6) << " " << expr->getNom () << " : " << expr->getDoc ();
+        }
+
     }
     return retour;
 }
